summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/batchprocessimages/borderoptionsdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/batchprocessimages/borderoptionsdialog.cpp')
-rw-r--r--kipi-plugins/batchprocessimages/borderoptionsdialog.cpp84
1 files changed, 42 insertions, 42 deletions
diff --git a/kipi-plugins/batchprocessimages/borderoptionsdialog.cpp b/kipi-plugins/batchprocessimages/borderoptionsdialog.cpp
index bc69173..70dcfbd 100644
--- a/kipi-plugins/batchprocessimages/borderoptionsdialog.cpp
+++ b/kipi-plugins/batchprocessimages/borderoptionsdialog.cpp
@@ -20,18 +20,18 @@
*
* ============================================================ */
-// Include files for Qt
-
-#include <qvbox.h>
-#include <qlayout.h>
-#include <qwidget.h>
-#include <qwhatsthis.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qgroupbox.h>
-#include <qstring.h>
-#include <qcombobox.h>
-#include <qcolor.h>
+// Include files for TQt
+
+#include <tqvbox.h>
+#include <tqlayout.h>
+#include <tqwidget.h>
+#include <tqwhatsthis.h>
+#include <tqlabel.h>
+#include <tqpushbutton.h>
+#include <tqgroupbox.h>
+#include <tqstring.h>
+#include <tqcombobox.h>
+#include <tqcolor.h>
// Include files for KDE
@@ -47,104 +47,104 @@
namespace KIPIBatchProcessImagesPlugin
{
-BorderOptionsDialog::BorderOptionsDialog(QWidget *parent, int BorderType)
- : KDialogBase( parent, "BorderOptionsDialog", true,
+BorderOptionsDialog::BorderOptionsDialog(TQWidget *tqparent, int BorderType)
+ : KDialogBase( tqparent, "BorderOptionsDialog", true,
i18n("Border Options"), Ok|Cancel, Ok, false)
{
- QWidget* box = new QWidget( this );
+ TQWidget* box = new TQWidget( this );
setMainWidget(box);
- QVBoxLayout *dvlay = new QVBoxLayout( box, 10, spacingHint() );
- QString whatsThis;
+ TQVBoxLayout *dvlay = new TQVBoxLayout( box, 10, spacingHint() );
+ TQString whatsThis;
if (BorderType == 0) // Solid
{
- QLabel *m_label_solidBorderWidth = new QLabel (i18n("Border width:"), box);
+ TQLabel *m_label_solidBorderWidth = new TQLabel (i18n("Border width:"), box);
dvlay->addWidget( m_label_solidBorderWidth );
m_solidBorderWidth = new KIntNumInput(25, box);
m_solidBorderWidth->setRange(1, 1000, 1, true );
- QWhatsThis::add( m_solidBorderWidth, i18n("<p>Select here the border width in pixels.") );
+ TQWhatsThis::add( m_solidBorderWidth, i18n("<p>Select here the border width in pixels.") );
m_label_solidBorderWidth->setBuddy( m_solidBorderWidth );
dvlay->addWidget( m_solidBorderWidth );
- QLabel *m_label_solidColor = new QLabel(i18n("Border color:"), box);
+ TQLabel *m_label_solidColor = new TQLabel(i18n("Border color:"), box);
dvlay->addWidget( m_label_solidColor );
- QColor solidBorderColor = QColor( 0, 0, 0 ); // Black per default.
+ TQColor solidBorderColor = TQColor( 0, 0, 0 ); // Black per default.
m_button_solidBorderColor = new KColorButton( solidBorderColor, box );
- QWhatsThis::add( m_button_solidBorderColor, i18n( "<p>You can select here the border color." ));
+ TQWhatsThis::add( m_button_solidBorderColor, i18n( "<p>You can select here the border color." ));
dvlay->addWidget( m_button_solidBorderColor );
}
if (BorderType == 1) // Niepce
{
- QLabel *m_label_lineNiepceBorderWidth = new QLabel (i18n("Line border width:"), box);
+ TQLabel *m_label_lineNiepceBorderWidth = new TQLabel (i18n("Line border width:"), box);
dvlay->addWidget( m_label_lineNiepceBorderWidth );
m_lineNiepceBorderWidth = new KIntNumInput(10, box);
m_lineNiepceBorderWidth->setRange(1, 500, 1, true );
- QWhatsThis::add( m_lineNiepceBorderWidth, i18n("<p>Select here the line border width in pixels.") );
+ TQWhatsThis::add( m_lineNiepceBorderWidth, i18n("<p>Select here the line border width in pixels.") );
m_label_lineNiepceBorderWidth->setBuddy( m_lineNiepceBorderWidth );
dvlay->addWidget( m_lineNiepceBorderWidth );
- QLabel *m_label_lineNiepceColor = new QLabel(i18n("Line border color:"), box);
+ TQLabel *m_label_lineNiepceColor = new TQLabel(i18n("Line border color:"), box);
dvlay->addWidget( m_label_lineNiepceColor );
- QColor lineNiepceBorderColor = QColor( 0, 0, 0 ); // Black per default.
+ TQColor lineNiepceBorderColor = TQColor( 0, 0, 0 ); // Black per default.
m_button_lineNiepceBorderColor = new KColorButton( lineNiepceBorderColor, box );
- QWhatsThis::add( m_button_lineNiepceBorderColor, i18n( "<p>You can select here the line border color." ));
+ TQWhatsThis::add( m_button_lineNiepceBorderColor, i18n( "<p>You can select here the line border color." ));
dvlay->addWidget( m_button_lineNiepceBorderColor );
- QLabel *m_label_NiepceBorderWidth = new QLabel (i18n("Border width:"), box);
+ TQLabel *m_label_NiepceBorderWidth = new TQLabel (i18n("Border width:"), box);
dvlay->addWidget( m_label_NiepceBorderWidth );
m_NiepceBorderWidth = new KIntNumInput(100, box);
m_NiepceBorderWidth->setRange(1, 500, 1, true );
- QWhatsThis::add( m_NiepceBorderWidth, i18n("<p>Select here the border width in pixels.") );
+ TQWhatsThis::add( m_NiepceBorderWidth, i18n("<p>Select here the border width in pixels.") );
m_label_NiepceBorderWidth->setBuddy( m_NiepceBorderWidth );
dvlay->addWidget( m_NiepceBorderWidth );
- QLabel *m_label_NiepceColor = new QLabel(i18n("Border color:"), box);
+ TQLabel *m_label_NiepceColor = new TQLabel(i18n("Border color:"), box);
dvlay->addWidget( m_label_NiepceColor );
- QColor NiepceBorderColor = QColor( 255, 255, 255 ); // White per default.
+ TQColor NiepceBorderColor = TQColor( 255, 255, 255 ); // White per default.
m_button_NiepceBorderColor = new KColorButton( NiepceBorderColor, box );
- QWhatsThis::add( m_button_NiepceBorderColor, i18n( "<p>You can select here the border color." ));
+ TQWhatsThis::add( m_button_NiepceBorderColor, i18n( "<p>You can select here the border color." ));
dvlay->addWidget( m_button_NiepceBorderColor );
}
if (BorderType == 2) // Raise
{
- QLabel *m_label_raiseBorderWidth = new QLabel (i18n("Border width:"), box);
+ TQLabel *m_label_raiseBorderWidth = new TQLabel (i18n("Border width:"), box);
dvlay->addWidget( m_label_raiseBorderWidth );
m_raiseBorderWidth = new KIntNumInput(50, box);
m_raiseBorderWidth->setRange(1, 500, 1, true );
- QWhatsThis::add( m_raiseBorderWidth, i18n("<p>Select here the border width in pixels.") );
+ TQWhatsThis::add( m_raiseBorderWidth, i18n("<p>Select here the border width in pixels.") );
m_label_raiseBorderWidth->setBuddy( m_raiseBorderWidth );
dvlay->addWidget( m_raiseBorderWidth );
}
if (BorderType == 3) // Frame
{
- QLabel *m_label_frameBorderWidth = new QLabel (i18n("Border width:"), box);
+ TQLabel *m_label_frameBorderWidth = new TQLabel (i18n("Border width:"), box);
dvlay->addWidget( m_label_frameBorderWidth );
m_frameBorderWidth = new KIntNumInput(25, box);
m_frameBorderWidth->setRange(0, 500, 1, true );
- QWhatsThis::add( m_frameBorderWidth, i18n("<p>Select here the border width in pixels.") );
+ TQWhatsThis::add( m_frameBorderWidth, i18n("<p>Select here the border width in pixels.") );
m_label_frameBorderWidth->setBuddy( m_frameBorderWidth );
dvlay->addWidget( m_frameBorderWidth );
- QLabel *m_label_frameBevelBorderWidth = new QLabel (i18n("Bevel width:"), box);
+ TQLabel *m_label_frameBevelBorderWidth = new TQLabel (i18n("Bevel width:"), box);
dvlay->addWidget( m_label_frameBevelBorderWidth );
m_frameBevelBorderWidth = new KIntNumInput(10, box);
m_frameBevelBorderWidth->setRange(0, 250, 1, true );
- QWhatsThis::add( m_frameBevelBorderWidth, i18n("<p>Select here the bevel width in pixels. "
+ TQWhatsThis::add( m_frameBevelBorderWidth, i18n("<p>Select here the bevel width in pixels. "
"This value must be <= Border width / 2") );
m_label_frameBevelBorderWidth->setBuddy( m_frameBevelBorderWidth );
dvlay->addWidget( m_frameBevelBorderWidth );
- QLabel *m_label_frameColor = new QLabel(i18n("Border color:"), box);
+ TQLabel *m_label_frameColor = new TQLabel(i18n("Border color:"), box);
dvlay->addWidget( m_label_frameColor );
- QColor frameBorderColor = QColor( 0, 0, 0 ); // Black per default.
+ TQColor frameBorderColor = TQColor( 0, 0, 0 ); // Black per default.
m_button_frameBorderColor = new KColorButton( frameBorderColor, box );
- QWhatsThis::add( m_button_frameBorderColor, i18n( "<p>You can select here the border color." ));
+ TQWhatsThis::add( m_button_frameBorderColor, i18n( "<p>You can select here the border color." ));
dvlay->addWidget( m_button_frameBorderColor );
- connect(m_frameBorderWidth, SIGNAL(valueChanged(int)), this, SLOT(slotFrameBorderWidthChanged(int)));
+ connect(m_frameBorderWidth, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotFrameBorderWidthChanged(int)));
}
}